==> monocle-gateway-osx-x64-v0.0.4.tar.gz: install.sh <==
#!/bin/bash -e
# *********************************************************************
#              __  __  ___  _  _  ___   ___ _    ___
#             |  \/  |/ _ \| \| |/ _ \ / __| |  | __|
#             | |\/| | (_) | .` | (_) | (__| |__| _|
#             |_|  |_|\___/|_|\_|\___/ \___|____|___|
#
#  -------------------------------------------------------------------
#                 MONOCLE GATEWAY INSTALL SCRIPT
#       COPYRIGHT SHADEBLUE, LLC @ 2019, ALL RIGHTS RESERVED
#  -------------------------------------------------------------------
#
# *********************************************************************

echo "-----------------------------------"
echo "Installing Monocle Gateway"
echo "-----------------------------------"

# REQUIRE 'sudo' PRIVILEGES
if [[ $(id -u) != 0 ]]; then
    echo "Please run this script with sudo:" >&2
    echo "sudo $0 $*" >&2
    exit 1
fi

# Move executables files to install locations
echo "Installing executables binaries to '/usr/local/bin'"
cp monocle-gateway /usr/local/bin/monocle-gateway
cp monocle-proxy /usr/local/bin/monocle-proxy

# Create required config directory
echo "Creating default configuration directory at '/etc/monocle/'"
mkdir -p /etc/monocle/

# Install launchd service file to install location
echo "Installing Monocle Gateway service daemon to '/Library/LaunchDaemons/com.monoclecam.gateway.plist'"
cp monocle-gateway.plist /Library/LaunchDaemons/com.monoclecam.gateway.plist

# Install Monocle Gateway as a system service
echo "Installing, loading, starting Monocle Gateway service daemon"
launchctl load /Library/LaunchDaemons/com.monoclecam.gateway.plist

echo "-----------------------------------"
echo "Monocle Gateway Installed"
echo "-----------------------------------"

==> monocle-gateway-osx-x64-v0.0.5.tar.gz: install.sh <==
#!/bin/bash -e
# *********************************************************************
#              __  __  ___  _  _  ___   ___ _    ___
#             |  \/  |/ _ \| \| |/ _ \ / __| |  | __|
#             | |\/| | (_) | .` | (_) | (__| |__| _|
#             |_|  |_|\___/|_|\_|\___/ \___|____|___|
#
#  -------------------------------------------------------------------
#                 MONOCLE GATEWAY INSTALL SCRIPT
#       COPYRIGHT SHADEBLUE, LLC @ 2019, ALL RIGHTS RESERVED
#  -------------------------------------------------------------------
#
# *********************************************************************

echo "-----------------------------------"
echo "Installing Monocle Gateway"
echo "-----------------------------------"

# REQUIRE 'sudo' PRIVILEGES
if [[ $(id -u) != 0 ]]; then
    echo "Please run this script with sudo:" >&2
    echo "sudo $0 $*" >&2
    exit 1
fi

# Move executables files to install locations
echo "Installing executables binaries to '/usr/local/bin'"
cp monocle-gateway /usr/local/bin/monocle-gateway
cp monocle-proxy /usr/local/bin/monocle-proxy

# Create required config directory
echo "Creating default configuration directory at '/etc/monocle/'"
mkdir -p /etc/monocle/

# Install launchd service file to install location
echo "Installing Monocle Gateway service daemon to '/Library/LaunchDaemons/com.monoclecam.gateway.plist'"
cp com.monoclecam.gateway.plist /Library/LaunchDaemons/com.monoclecam.gateway.plist

# Install Monocle Gateway as a system service
echo "Installing, loading, starting Monocle Gateway service daemon"
launchctl load /Library/LaunchDaemons/com.monoclecam.gateway.plist

echo "-----------------------------------"
echo "Monocle Gateway Installed"
echo "-----------------------------------"
